summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorRay <[email protected]>2019-09-12 16:28:58 +0200
committerRay <[email protected]>2019-09-12 16:28:58 +0200
commit7e08b312d5b8762fdd17d5d254cb592e97dbd332 (patch)
treef12aed5f2b9727cc19ec6e1e91246650a684a61b
parentc6d2502bdbdcdbbcbf89795e4574dcff26ad9949 (diff)
downloadraylib-7e08b312d5b8762fdd17d5d254cb592e97dbd332.tar.gz
raylib-7e08b312d5b8762fdd17d5d254cb592e97dbd332.zip
RENAMED: text_bmfont_ttf > text_font_loading
-rw-r--r--examples/text/text_font_loading.c (renamed from examples/text/text_bmfont_ttf.c)19
-rw-r--r--examples/text/text_font_loading.png (renamed from examples/text/text_bmfont_ttf.png)bin20086 -> 20086 bytes
2 files changed, 14 insertions, 5 deletions
diff --git a/examples/text/text_bmfont_ttf.png b/examples/text/text_font_loading.png
index a99027ad..a99027ad 100644
--- a/examples/text/text_bmfont_ttf.png
+++ b/examples/text/text_font_loading.png
Binary files differ
diff --git a/examples/text/text_bmfont_ttf.c b/examples/text/text_font_loading.c
index 0fc82e97..7eaaed8f 100644
--- a/examples/text/text_bmfont_ttf.c
+++ b/examples/text/text_font_loading.c
@@ -1,11 +1,20 @@
/*******************************************************************************************
*
* raylib [text] example - BMFont and TTF Fonts loading
*
-* This example has been created using raylib 1.4 (www.raylib.com)
+* raylib can load fonts from multiple file formats:
+*
+* - TTF/OTF > Sprite font atlas is generated on loading, user can configure
+* some of the generation parameters (size, characters to include)
+* - BMFonts > Angel code font fileformat, sprite font image must be provided
+* together with the .fnt file, font generation cna not be configured
+* - XNA Spritefont > Sprite font image, following XNA Spritefont conventions,
+* Characters in image must follow some spacing and order rules
+*
+* This example has been created using raylib 2.6 (www.raylib.com)
* raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
-* Copyright (c) 2016 Ramon Santamaria (@raysan5)
+* Copyright (c) 2016-2019 Ramon Santamaria (@raysan5)
*
********************************************************************************************/
@@ -18,7 +27,7 @@ int main(void)
const int screenWidth = 800;
const int screenHeight = 450;
- InitWindow(screenWidth, screenHeight, "raylib [text] example - bmfont and ttf sprite fonts loading");
+ InitWindow(screenWidth, screenHeight, "raylib [text] example - font loading");
// Define characters to draw
// NOTE: raylib supports UTF-8 encoding, following list is actually codified as UTF8 internally
@@ -75,7 +84,7 @@ int main(void)
UnloadFont(fontBm); // AngelCode Font unloading
UnloadFont(fontTtf); // TTF Font unloading
- CloseWindow(); // Close window and OpenGL context
+ CloseWindow(); // Close window and OpenGL context
//--------------------------------------------------------------------------------------
return 0;
@@ -1,11 +1,20 @@
/*******************************************************************************************
*
-* raylib [text] example - BMFont and TTF Fonts loading
+* raylib [text] example - Font loading
*